@@ -39,8 +39,8 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
 ### ggplot2 calls for GraphSpace-class methods
 ################################################################################
 .set.gspace <- function(nodes, xlab, ylab, cl){
-    X <- Y <- NULL
-    ggp <- ggplot2::ggplot(nodes, ggplot2::aes(X, Y)) +
+    x <- y <- NULL
+    ggp <- ggplot2::ggplot(nodes, ggplot2::aes(x, y)) +
         ggplot2::scale_x_continuous(name = xlab, breaks = cl$axis.ticks,
             labels = format(cl$axis.ticks), position = cl$x.position,
             limits = cl$xylim, expand = ggplot2::expansion(mult = 0)) +
@@ -51,6 +51,60 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
     return(ggp)
 }
 
+#-------------------------------------------------------------------------------
+.add.labels1 <- function(ggp, nodes, node.labels, label.size, label.color){
+  node.labels <- node.labels[!duplicated(node.labels)]
+  if (is.null(names(node.labels))) names(node.labels) <- node.labels
+  names(node.labels) <- ifelse(is.na(names(node.labels)), node.labels, names(node.labels))
+  names(node.labels) <- ifelse(names(node.labels) == "", node.labels, names(node.labels))
+  idx_df <- .get.label.idx(node.labels, nodes)
+  if(any(is.na(idx_df$idx))){
+    stop("All 'node.labels' should be annotated in the 'PathwaySpace' object.",
+      call. = FALSE)
+  }
+  nodes_ft <- nodes[idx_df$idx, , drop = FALSE]
+  nodes_ft$ID <- idx_df$label
+  ID <- NULL
+  ggp <- ggp + ggplot2::geom_text(mapping = aes(label = ID), 
+    data = nodes_ft, fontface = "bold", size.unit = "mm",
+    size = label.size, colour = label.color, 
+    vjust="center", hjust="center")
+  return(ggp)
+}
+.get.label.idx <- function(node.labels, nodes){
+  idx_df <- data.frame(name=node.labels, label=names(node.labels))
+  idx_df$name1 <- match(node.labels, nodes$name)
+  idx_df$name2 <- match(names(node.labels), nodes$name)
+  idx_df$labl1  <- match(node.labels, nodes$nodeLabel)
+  idx_df$labl2  <- match(names(node.labels), nodes$nodeLabel)
+  idx_df$idx <- sapply(seq_len(nrow(idx_df)), function(i){
+    idx <- idx_df[i,seq.int(3,6)]
+    idx[!is.na(idx)][1]
+  })
+  idx_df <- idx_df[,c(1,2,7)]
+  return(idx_df)
+}
+
+
+#-------------------------------------------------------------------------------
+.add.labels2 <- function(ggp, nodes){
+  nodes_ft <- nodes[!is.na(nodes$nodeLabel), ]
+  nodeLabel <- NULL
+  ggp <- ggp + geom_text(mapping = aes(label = nodeLabel), 
+    data = nodes_ft, fontface = "bold",
+    size = nodes_ft$nodeLabelSize, 
+    colour = nodes_ft$nodeLabelColor, 
+    size.unit = "pt",
+    vjust="center", hjust="center")
+  return(ggp)
+}
+
+#-------------------------------------------------------------------------------
+.add.image <- function(ggp, image){
+  ggp <- ggp + annotation_raster(image, xmin = 0, xmax = 1, ymin = 0, ymax = 1)
+  return(ggp)
+}
+
 #-------------------------------------------------------------------------------
 .add.graph <- function(ggp, nodes, edges){
     if(nrow(edges)>0){
@@ -152,56 +206,6 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
     return(list(exy=exy, arrow=arrow))
 }
 
-#-------------------------------------------------------------------------------
-.add.node.marks <- function(ggp, nodes, marks, mark.color, mark.size) {
-    marks <- .set.labmarks(nodes, marks)
-    if (length(mark.color) > 1) {
-        if (is.null(names(mark.color))) {
-            stop("'mark.color' should be named for this call!", call. = FALSE)
-        }
-        if (!all(marks %in% names(mark.color))) {
-            stop("All 'marks' should be listed in 'mark.color' names!",
-                call. = FALSE)
-        }
-        mark.color <- mark.color[marks]
-    }
-    if (length(mark.size) > 1) {
-        if (is.null(names(mark.size))) {
-            stop("'mark.size' should be named for this call!", call. = FALSE)
-        }
-        if (!all(marks %in% names(mark.size))) {
-            stop("All 'marks' should be listed in 'mark.size' names!",
-                call. = FALSE)
-        }
-        mark.size <- mark.size[marks]
-    }
-    nodes$mark.color <- mark.color
-    nodes$mark.size <- mark.size
-    nodes <- nodes[marks, , drop = FALSE]
-    nodes$ID <- names(marks); ID <- NULL
-    ggp <- ggp + ggplot2::geom_text(mapping = aes(label = ID), 
-        data = nodes, fontface = "bold",
-        size = mark.size, colour = mark.color, 
-        vjust="center", hjust="center")
-    return(ggp)
-}
-.set.labmarks <- function(nodes, marks){
-    nodelabs <- nodes[,c("name","nodeLabel")]
-    if(is.logical(marks)){
-        marks <- rownames(nodelabs)
-    } else {
-        marks <- marks[marks %in% rownames(nodelabs)]
-        nodelabs <- nodelabs[marks, ]
-    }
-    if (is.null(names(marks))){
-        names(marks) <- marks
-        idx <- !is.na(nodelabs$nodeLabel)
-        names(marks)[idx] <- nodelabs$nodeLabel[idx]
-    }
-    names(marks) <- ifelse(names(marks) == "", marks, names(marks))
-    return(marks)
-}
-
 #-------------------------------------------------------------------------------
 .custom.themes <- function(gg, theme, font.size, bg.color) {
     et1 <- ggplot2::element_text(size = 14 * font.size)
@@ -210,12 +214,14 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
         gg <- .custom.th3(gg, font.size, bg.color)
     } else if (theme == "th2") {
         gg <- .custom.th2(gg, font.size, bg.color)
+    } else if (theme == "th1") {
+      gg <- .custom.th1(gg, font.size, bg.color) 
     } else {
-        gg <- .custom.th1(gg, font.size, bg.color)
+        gg <- .custom.th0(gg, font.size, bg.color)
     }
     return(gg)
 }
-.custom.th1 <- function(gg, font.size, bg.color) {
+.custom.th0 <- function(gg, font.size, bg.color) {
     et1 <- ggplot2::element_text(size = 14 * font.size)
     et2 <- ggplot2::element_text(size = 12 * font.size)
     gg <- gg + ggplot2::theme(axis.title = et1, axis.text = et2,
@@ -223,6 +229,26 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
         panel.background = element_rect(fill = bg.color))
     return(gg)
 }
+.custom.th1 <- function(gg, font.size, bg.color) {
+  et1 <- ggplot2::element_text(size = 14 * font.size)
+  et2 <- ggplot2::element_text(size = 12 * font.size)
+  gg <- gg + ggplot2::theme_bw() +
+    ggplot2::theme(axis.title = et1,
+      axis.text = et2, legend.title = et2,
+      legend.text = et2, legend.margin = margin(0, 0, 0, 0), 
+      plot.margin = margin(1, 1, 1, 1), 
+      legend.background = element_blank(),
+      legend.box.background = element_blank(),
+      panel.grid.minor = element_line(linewidth = 0.7, 
+        colour = bg.color),
+      panel.grid.major = element_line(linewidth = 0.7,
+        colour = bg.color),
+      legend.position = "none",
+      axis.ticks = element_line(linewidth = 0.7),
+      axis.line = element_blank(),
+      panel.border = element_rect(linewidth = 1.2))
+  return(gg)
+}
 .custom.th2 <- function(gg, font.size, bg.color) {
     et1 <- ggplot2::element_text(size = 14 * font.size)
     et2 <- ggplot2::element_text(size = 12 * font.size)
@@ -232,7 +258,6 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
         plot.margin = margin(5, 10, 0, 10), 
         legend.background = element_blank(),
         legend.box.background = element_blank(),
-        plot.background = element_blank(), 
         panel.grid.minor = element_blank(),
         panel.grid.major = element_blank(),
         legend.position = "none",
@@ -244,18 +269,18 @@ GeomNodeSpace <- ggproto("GeomNodeSpace", Geom,
 .custom.th3 <- function(gg, font.size, bg.color) {
     et1 <- ggplot2::element_text(size = 14 * font.size)
     et2 <- ggplot2::element_text(size = 12 * font.size)
-    gg <- gg + ggplot2::theme_gray() + ggplot2::theme(axis.title = et1,
-        axis.text = et2, legend.title = element_text(size = 12 * 
-                font.size, vjust = 1), legend.text = et2,
+    gg <- gg + ggplot2::theme_gray() + 
+        ggplot2::theme(axis.title = et1, axis.text = et2, 
+        legend.title = element_text(size = 12 * font.size, vjust = 1), 
+        legend.text = et2,
         legend.margin = margin(0, 0, 0, 0),
+        legend.position = "none",
         plot.margin = margin(5, 5, 5, 5), 
         legend.box.margin = margin(0, 0, 0, 0), 
         legend.background = element_blank(),
         legend.box.background = element_blank(),
-        plot.background = element_blank(), 
         panel.grid.minor = element_blank(),
         panel.grid.major = element_blank(),
-        legend.position = "none",
         axis.ticks = element_line(linewidth = 0.5),
         axis.line = element_blank(), panel.border = element_blank(),
         panel.background = element_rect(fill = bg.color))
